%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%



function AbsorbingLayerDecomp(InputU,dim,a,b,MaxLength,WPML,DeltaX,CoeffC,CoeffD,evecR,eff_nR,wavenumber)
  

xmin=-(MaxLength+WPML); % from xmin (in cover)
xmax=MaxLength+WPML; % to xmax (in substrate)
[C I] = max(abs(CoeffC));
ExpandInputUFund=evecR(:,I)*(CoeffC(I)./CoeffD(I));
lambda=2*pi/wavenumber;

ModeIndexRange=[476 476; 470 480; 465 485; 460 490; 450 500; 440 500; 430 500;420 500;
      410 500; 400 500; 350 500; 300 500;250 500; 200 500;150 500;100 500;50 500;1 500];
  FONT_SIZE=30;
  for jj=1:length(ModeIndexRange(:,1))

    fprintf('Generating figure %d/%d\n',jj,length(ModeIndexRange(:,1)));

  
      
    ExpandInputUMovie=0;
    for ii=ModeIndexRange(jj,1):ModeIndexRange(jj,2)
        ExpandInputUMovie=ExpandInputUMovie+evecR(:,ii)*(CoeffC(ii)./CoeffD(ii));
    end;
    figure(100);
    subplot(2,1,1);
    pos = get(gca, 'Position');
    set(gca,'Position', [pos(1) pos(2)-0.0 pos(3) pos(4)]);
    hold off;
    plot(xmin+((1:dim)-1)*DeltaX,real(InputU),'b','linewidth',2);hold on;
    plot(xmin+((1:dim)-1)*DeltaX,real(ExpandInputUMovie),'r--','linewidth',2);
        
    ylim([-0.3 1.3]);
    set(gca,'ytick',[0 0.5 1],'YTickLabel',[]);
    set(gca,'xtick',[-30 -20 -10 0 10 20 30],'XTickLabel',[]);
    tls = [0.02 0.25];set(gca,'TickLength',tls);
 	htxt14 = text(0,0,'(a)');
	set(htxt14,'Position',[22 0.8],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);

    plot([a/lambda a/lambda],[-0.3 1.3],'k-.','LineWidth',2);
    plot([-a/lambda -a/lambda],[-0.3 1.3],'k-.','LineWidth',2);
    plot([b/lambda b/lambda],[-0.3 1.3],'k--','LineWidth',2);
    plot([-b/lambda -b/lambda],[-0.3 1.3],'k--','LineWidth',2);
    plot([MaxLength/lambda MaxLength/lambda],[-0.3 1.3],'k:','LineWidth',2);
    plot([-MaxLength/lambda -MaxLength/lambda],[-0.3 1.3],'k:','LineWidth',2);
    
    subplot(2,1,2);
    pos = get(gca, 'Position');
    set(gca,'Position', [pos(1) pos(2) pos(3) pos(4) ]);
    hold off;
    plot(xmin+((1:dim)-1)*DeltaX,real(InputU),'b','linewidth',2);hold on;
    plot(xmin+((1:dim)-1)*DeltaX,real(ExpandInputUMovie),'r--','linewidth',2);
    xlim([-2 2]);ylim([-0.3 1.3]);
    set(gca,'ytick',[0 0.5 1],'YTickLabel',[]);
    set(gca,'xtick',[-2 -1 0 1 2],'XTickLabel',[]);
    tls = [0.02 0.25];set(gca,'TickLength',tls);
 
    plot([a/lambda a/lambda],[-0.3 1.3],'k-.','LineWidth',2);
    plot([-a/lambda -a/lambda],[-0.3 1.3],'k-.','LineWidth',2);
    plot([b/lambda b/lambda],[-0.3 1.3],'k--','LineWidth',2);
    plot([-b/lambda -b/lambda],[-0.3 1.3],'k--','LineWidth',2);
    plot([MaxLength/lambda MaxLength/lambda],[-0.3 1.3],'k:','LineWidth',2);
    plot([-MaxLength/lambda -MaxLength/lambda],[-0.3 1.3],'k:','LineWidth',2);
    
    texttemp = (['Mode indices from ' num2str(ModeIndexRange(jj,1)) ' to ' num2str(ModeIndexRange(jj,2))]);
    htxt = text(0,0,texttemp);
    set(htxt,'Position',[-1.2 3.7],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE/1.3);
    htxt = text(0,0,'{\it x} /{\it \lambda}');
    set(htxt,'Position',[-0.3 1.7],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
    htxt = text(0,0,'{\it x} /{\it \lambda}');
    set(htxt,'Position',[-0.3 -0.55],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
  	htxt = text(0,0,'Re[{\it E}({\it x})]');
	set(htxt,'Rotation',90,'Position',[-2.4 0.1],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE/1.4);
	htxt = text(0,0,'Re[{\it E}({\it x})]');
	set(htxt,'Rotation',90,'Position',[-2.4 2.2],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE/1.4);
	htxt = text(0,0,'-2');
	set(htxt,'Position',[-2.1 -0.55],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE/1.2);
	htxt = text(0,0,'2');
	set(htxt,'Position',[1.9 -0.55],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE/1.2);
	htxt = text(0,0,'-30');
	set(htxt,'Position',[-2.1 1.7],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE/1.2);
	htxt = text(0,0,'30');
	set(htxt,'Position',[1.9 1.7],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE/1.2);
	htxt = text(0,0,'0');
	set(htxt,'Position',[-2.2 0],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE/1.2);
	htxt = text(0,0,'1');
	set(htxt,'Position',[-2.2 1],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE/1.2);
	htxt = text(0,0,'0');
	set(htxt,'Position',[-2.2 2.2],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE/1.2);
	htxt = text(0,0,'1');
	set(htxt,'Position',[-2.2 3.2],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE/1.2);
	htxt = text(0,0,'(b)');
	set(htxt,'Position',[1.45 0.8],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);

  

    
    m=100+jj;
    print('-dpsc2',strcat('movie/Fig30_',int2str(m),'.ps'));
    % mogrify -format gif *ps

  end;