%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%
function [Coeff alpha] = BandgapGetCouplingCoeff(PulseWidth,na,n1,n2,t,pitch,N,...
            XLength,deltaX,wavenumber,beta,ShinkXLengthFactor,plotsign);
sq=inline('x.*x','x');

a=pitch/2;
b=pitch/2;
load data/Endwithn1sign.dat;


k1x=sqrt(sq(wavenumber*n1)-sq(beta));
k2x=sqrt(sq(wavenumber*n2)-sq(beta));
A=exp(-i*k1x*a).*(cos(k2x*b)-i/2*(k2x./k1x+k1x./k2x).*sin(k2x*b));
B=exp(i*k1x*a).*(-i/2*(k2x./k1x-k1x./k2x).*sin(k2x*b));
C=exp(-i*k1x*a).*(i/2*(k2x./k1x-k1x./k2x).*sin(k2x*b));
D=exp(i*k1x*a).*(cos(k2x*b)+i/2*(k2x./k1x+k1x./k2x).*sin(k2x*b));
K=1/pitch*acos(1/2*(A+D));
K = real(K)+i*abs(imag(K));
1/2*(A+D)-sqrt(sq(1/2*(A+D))-1);
ka=sqrt(sq(wavenumber*na)-sq(beta));
q=-i*k1x;


% start to plot radiation mode

alpha=1;
a0=alpha/2*(cos(ka*t/2)+i*sin(ka*t/2).*ka./k1x);
b0=alpha/2*(cos(ka*t/2)-i*sin(ka*t/2).*ka./k1x);
abii = [a0; b0];
x=[];E=[];
xa=0:deltaX:t/2;
Ea=alpha*cos(ka*xa);
x=[x xa];E=[E Ea];

abTocd0 = [exp(-i*k2x*pitch) exp(i*k2x*pitch); k2x/k1x*exp(-i*k2x*pitch) -k2x/k1x*exp(i*k2x*pitch)];
abTocd = inv(abTocd0)*[1 1; 1 -1];
ABCD = [A B;C D];
abToab = inv([A B;C D]);
for ii=1:N
    cdii=abTocd*abii;
    abii=abToab*abii;

    xiicd=(ii-1)*pitch+deltaX:deltaX:(ii-1)*pitch+pitch/2;
    Eiicd=cdii(1)*exp(i*k2x*(xiicd-ii*pitch))+cdii(2)*exp(-i*k2x*(xiicd-ii*pitch));
    xiiab=(ii-1)*pitch+pitch/2+deltaX:deltaX:(ii-1)*pitch+pitch;
    Eiiab=abii(1)*exp(i*k1x*(xiiab-ii*pitch))+abii(2)*exp(-i*k1x*(xiiab-ii*pitch));

    x=[x xiicd+t/2];    E=[E Eiicd];    x=[x xiiab+t/2];    E=[E Eiiab];
end;




if(Endwithn1sign==1)
     xN=linspace(N*pitch+deltaX,XLength/ShinkXLengthFactor-t/2,...
            round((XLength/ShinkXLengthFactor-t/2-(N*pitch+deltaX))/deltaX)+1);
   EN=abii(1)*exp(i*k1x*(xN-ii*pitch))+abii(2)*exp(-i*k1x*(xN-ii*pitch));
    normlizeCoeff=2*abs(abii(1));
else
    convert12 = [1+k2x./k1x 1-k2x./k1x; 1-k2x./k1x 1+k2x./k1x]/2;
    cdii = inv(convert12)*abii;
    xN=linspace(N*pitch+deltaX,XLength/ShinkXLengthFactor-t/2,...
            round((XLength/ShinkXLengthFactor-t/2-(N*pitch+deltaX))/deltaX)+1);
    EN=cdii(1)*exp(i*k2x*(xN-N*pitch))+cdii(2)*exp(-i*k2x*(xN-N*pitch));
   

    % normlizeCoeff=max(abs(EN))
     normlizeCoeff=2*abs(cdii(1));
     
   %   cdii(1)*exp(i*k2x*(-20*pitch));
end;
 
x=[x xN+t/2];    E=[E EN];

  E=E/normlizeCoeff;
 alpha=alpha/normlizeCoeff;
    fx=exp(-x.^2/2/PulseWidth/PulseWidth);
    Coeff = 2*sum(fx.*E)/pi*deltaX-E(1)*fx(1)/pi*deltaX;





    

if(plotsign==1)
figure(1);hold off;
plot(x/pitch, real(E)/normlizeCoeff); hold on;
plot([-t/pitch/2; -t/pitch/2],[1.5;-1.5],'r-.');
plot([t/pitch/2; t/pitch/2],[1.5;-1.5],'r-.');
plot([-(N*pitch + t/2)/pitch; -(N*pitch + t/2)/pitch],[1.5;-1.5],'r--');
plot([(N*pitch + t/2)/pitch; (N*pitch + t/2)/pitch],[1.5;-1.5],'r--');
end;





