%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%
function [x E]=BandgapLeakyMode(neff,na,n1,n2,t,pitch,N,wavenumber,XLength);

sq=inline('x.*x','x');

load data/Endwithn1sign.dat;
numlayer=N;
beta = neff*wavenumber;
a=pitch/2;
b=pitch/2;

k1x=sqrt(sq(wavenumber*n1)-sq(beta));
k2x=sqrt(sq(wavenumber*n2)-sq(beta));
A=exp(-i*k1x*a).*(cos(k2x*b)-i/2*(k2x./k1x+k1x./k2x).*sin(k2x*b));
B=exp(i*k1x*a).*(-i/2*(k2x./k1x-k1x./k2x).*sin(k2x*b));
C=exp(-i*k1x*a).*(i/2*(k2x./k1x-k1x./k2x).*sin(k2x*b));
D=exp(i*k1x*a).*(cos(k2x*b)+i/2*(k2x./k1x+k1x./k2x).*sin(k2x*b));
K=1/pitch*acos(1/2*(A+D));
K = real(K)+i*abs(imag(K));
K/pi;
exp(-i*K*pitch);
1/2*(A+D)-sqrt(sq(1/2*(A+D))-1);


ka=sqrt(sq(wavenumber*na)-sq(beta));
q=-i*k1x;


a0= (A.*YehUN(numlayer-1,K,pitch)-YehUN(numlayer-2,K,pitch)).*(1+k2x./k1x)/2 +B.*YehUN(numlayer-1,K,pitch).*(1-k2x./k1x)/2;
b0= C.*YehUN(numlayer-1,K,pitch).*(1+k2x./k1x)/2+(D.*YehUN(numlayer-1,K,pitch)-YehUN(numlayer-2,K,pitch)).*(1-k2x./k1x)/2;
abii = [a0; b0];
alpha=(a0+b0)/cos(ka*t/2);
x=[];E=[];
xa=0:t/100:t/2;
Ea=alpha*cos(ka*xa);
x=[x xa];E=[E Ea];


abTocd0 = [exp(-i*k2x*pitch) exp(i*k2x*pitch); k2x/k1x*exp(-i*k2x*pitch) -k2x/k1x*exp(i*k2x*pitch)];
abTocd = inv(abTocd0)*[1 1; 1 -1];
ABCD = [A B;C D];
cdii=abTocd*abii;
abToab = inv([A B;C D]);
for ii=1:N
    cdii=abTocd*abii;
    abii=abToab*abii;

    xiicd=(ii-1)*pitch:pitch/100:(ii-1)*pitch+pitch/2;
    Eiicd=cdii(1)*exp(i*k2x*(xiicd-ii*pitch))+cdii(2)*exp(-i*k2x*(xiicd-ii*pitch));
    xiiab=(ii-1)*pitch+pitch/2:pitch/100:(ii-1)*pitch+pitch;
    Eiiab=abii(1)*exp(i*k1x*(xiiab-ii*pitch))+abii(2)*exp(-i*k1x*(xiiab-ii*pitch));

    x=[x xiicd+t/2];    E=[E Eiicd];    x=[x xiiab+t/2];    E=[E Eiiab];
end;

if(Endwithn1sign==1)
    xN=N*pitch:pitch/100:XLength-t/2-N*pitch;
    EN=abii(1)*exp(i*k2x*(xN-ii*pitch));
else
    convert12 = [1+k2x./k1x 1-k2x./k1x; 1-k2x./k1x 1+k2x./k1x]/2;
    cdii = inv(convert12)*abii;
    xN=N*pitch:pitch/100:XLength-t/2-N*pitch;
    EN=cdii(1)*exp(i*k2x*(xN-ii*pitch));
end;
%fprintf('evaluate x.r=%1.10f x.i=%1.10f  \n',real(k1x/wavenumber),imag(k1x/wavenumber));

 
x=[x xN+t/2];    E=[E EN];
 
%figure(numbermodes+1);hold on;
x = [-1*fliplr(x(2:end)) x];
E = [fliplr(E(2:end)) E];
E=E/max(abs(E));
    
plot(x/pitch, real(E)/max(real(E))); hold on;
plot([-t/pitch/2; -t/pitch/2],[1.5;-1.5],'r-.');
plot([t/pitch/2; t/pitch/2],[1.5;-1.5],'r-.');
plot([-(N*pitch + t/2)/pitch; -(N*pitch + t/2)/pitch],[1.5;-1.5],'r--');
plot([(N*pitch + t/2)/pitch; (N*pitch + t/2)/pitch],[1.5;-1.5],'r--');



