%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%
function deltaneff = BandgapPerturbation(na,n1,n2,t,pitch,N,wavenumber,beta0)

sq=inline('x.*x','x');



numlayer=N;


a=pitch/2;
b=pitch/2;




ka0=sqrt(sq(wavenumber*na)-sq(beta0));
k1x0=sqrt(sq(wavenumber*n1)-sq(beta0));
k2x0=sqrt(sq(wavenumber*n2)-sq(beta0));
A0=exp(-i*k1x0*a).*(cos(k2x0*b)-i/2*(k2x0./k1x0+k1x0./k2x0).*sin(k2x0*b));
B0=exp(i*k1x0*a).*(-i/2*(k2x0./k1x0-k1x0./k2x0).*sin(k2x0*b));
C0=exp(-i*k1x0*a).*(i/2*(k2x0./k1x0-k1x0./k2x0).*sin(k2x0*b));
D0=exp(i*k1x0*a).*(cos(k2x0*b)+i/2*(k2x0./k1x0+k1x0./k2x0).*sin(k2x0*b));
K0=1/pitch*acos(1/2*(A0+D0));
K0 = real(K0)+i*abs(imag(K0));





deltak1x=-1/k1x0;
deltak2x=-1/k2x0;

deltaA=deltak1x*(-i*a)*exp(-i*k1x0*a)*(cos(k2x0*b)-i/2*(k2x0./k1x0+k1x0./k2x0).*sin(k2x0*b))...
    +exp(-i*k1x0*a)*(-deltak2x*b*sin(k2x0*b)-i/2*(k2x0/k1x0+k1x0/k2x0)*deltak2x*b*cos(k2x0*b)...
    -i/2*(-1*(deltak1x/k1x0-deltak2x/k2x0)*(k2x0/k1x0-k1x0/k2x0)*sin(k2x0*b)));
deltaB=deltak1x*(i*a)*exp(i*k1x0*a)*(-i/2*(k2x0./k1x0-k1x0./k2x0).*sin(k2x0*b))...
    +exp(i*k1x0*a)*(-i/2*(k2x0/k1x0-k1x0/k2x0)*deltak2x*b*cos(k2x0*b)...
    -i/2*(-1*(deltak1x/k1x0-deltak2x/k2x0)*(k2x0/k1x0+k1x0/k2x0)*sin(k2x0*b)));
deltaC=deltak1x*(-i*a)*exp(-i*k1x0*a)*(i/2*(k2x0./k1x0-k1x0./k2x0).*sin(k2x0*b))...
    +exp(-i*k1x0*a)*(i/2*(k2x0/k1x0-k1x0/k2x0)*deltak2x*b*cos(k2x0*b)...
    +i/2*(-1*(deltak1x/k1x0-deltak2x/k2x0)*(k2x0/k1x0+k1x0/k2x0)*sin(k2x0*b)));
deltaD=deltak1x*(i*a)*exp(i*k1x0*a)*(cos(k2x0*b)+i/2*(k2x0./k1x0+k1x0./k2x0).*sin(k2x0*b))...
    +exp(i*k1x0*a)*(-deltak2x*b*sin(k2x0*b)+i/2*(k2x0/k1x0+k1x0/k2x0)*deltak2x*b*cos(k2x0*b)...
    +i/2*(-1*(deltak1x/k1x0-deltak2x/k2x0)*(k2x0/k1x0-k1x0/k2x0)*sin(k2x0*b)));

deltaexpK=(deltaA+deltaD)/2+(A0+D0)/2*(deltaA+deltaD)/2/sqrt(sq((A0+D0)/2)-1);

G=B0/(exp(-i*K0*pitch)-A0);





Coeffbeta = ((1+k2x0/k1x0)+(1-k2x0/k1x0)*B0/conj(cos(K0*pitch)-i*sin(K0*pitch)-A0))*(sq(G)-1)/2/G...
    *(-1/sq(ka0)-1/ka0*t/2*(1+sq(tan(ka0*t/2)))/tan(ka0*t/2)+1/sq(k1x0))...
-((deltaA-deltaexpK)/conj(cos(K0*pitch)-i*sin(K0*pitch)-A0)...
    -B0*deltaC/sq(abs(A0-cos(K0*pitch)-i*sin(K0*pitch))))*(1+k2x0/k1x0)...
    -(deltaB/B0-(deltaD-deltaexpK)/(cos(K0*pitch)-i*sin(K0*pitch)-A0))...
       *(1-k2x0/k1x0)*B0/conj(cos(K0*pitch)-i*sin(K0*pitch)-A0);

deltabeta =(-2*i*exp(-2*numlayer*imag(K0)*pitch)*sin(K0*pitch)/conj(cos(K0*pitch)-i*sin(K0*pitch)-A0)*(1+k2x0/k1x0)...
+2*i*exp(-2*numlayer*imag(K0)*pitch)*sin(K0*pitch)/(cos(K0*pitch)-i*sin(K0*pitch)-A0)...
    *B0/conj(cos(K0*pitch)-i*sin(K0*pitch)-A0)*(1-k2x0/k1x0))/Coeffbeta/beta0;

deltaneff = deltabeta/wavenumber;



