%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%

function FigureNumber(FigNum)

if FigNum==1 ||FigNum==2 || FigNum==10 || FigNum==16 || FigNum==23 
    fprintf('Figure %d was generated using xfig.\n', FigNum);


end;

% Uniformmedium

if FigNum>=3 && FigNum<=5
    Uniformmedium(1000,500,FigNum);
end;

%Three-Layer slab waveguide

if FigNum==6
    ThreeLayer(2000,500,10,6);
end;

if FigNum==7
    ThreeLayer(2000,1000,100,7);
end;

if FigNum==8
    ThreeLayer(3000,2000,5,8);
end;

if FigNum==9
    WTypeLeaky(1.45,0.96*1.45,5,2*pi/1e-6,1);
end;

% W-type slab waveguide

if FigNum==11
    WType(2000,2000,1.2,5,1,11); 
end;

if FigNum==12
    WType(1000,2000,1.2,5,1,12);
end;

if FigNum==13
    WType(1000,2000,1.2,2,50,13);
end;

if FigNum==14
    WType(5000,8000,1.2,5,50,14); 
end;

if FigNum==15
    WType(2000,2000,1.2,2.5,1,15);
end;


% Bandgap

if FigNum==17
    BandgapPlotAD(1,2.89,3.38,1.2e-6,0.2e-6);
end;

if FigNum==18
    BandgapInfinity(1,2.89,3.38,1.2e-6,0.2e-6,2*pi/1.15e-6,1);
end;

if FigNum>=19 && FigNum<=22
    if FigNum==21
        Bandgap(15000,0.3,10,500,FigNum);
    else
        Bandgap(1000,0.3,10,20,FigNum);
    end;
end;

%Waveguide with absorbing layers

if FigNum==24
    Result=AbsorbingLayerapp(1,5e-6,16);
    figure;plot(Result(:,1),Result(:,3),'b-.','linewidth',2);
    Result=AbsorbingLayerapp(1,10e-6,16);
    hold on;plot(Result(:,1),Result(:,3),'b--','linewidth',2);
    Result=AbsorbingLayerapp(1,15e-6,16);
    plot(Result(:,1),Result(:,3),'b:','linewidth',2);

    n1=1.45;
    n2=0.96*n1;
    [realne imagne] =WTypeLeaky(n1,n2,5,2*pi/1e-6,0);
    plot(Result(:,1),imagne*ones(size(Result(:,1))),'r');
    xlabel('L/\lambda');
    ylabel('Im(n_{eff})x10^4');
end;

if FigNum==25
    Result=AbsorbingLayerapp(5,15e-6,16);
    figure;plot(Result(:,1),Result(:,3),'b-.','linewidth',2);
    Result=AbsorbingLayerapp(2,15e-6,16);
    hold on;plot(Result(:,1),Result(:,3),'b--','linewidth',2);
    Result=AbsorbingLayerapp(1,15e-6,16);
    plot(Result(:,1),Result(:,3),'b:','linewidth',2);

    n1=1.45;
    n2=0.96*n1;
    [realne imagne] =WTypeLeaky(n1,n2,5,2*pi/1e-6,0);
    plot(Result(:,1),imagne*ones(size(Result(:,1))),'r');
    xlabel('L/\lambda');
    ylabel('Im(n_{eff})x10^4');
end;

if FigNum==26
    sPParray=logspace(-2,1,50);
    MatrixsPP=zeros(length(sPParray),3);
    for ii=1:length(sPParray)
        Matrix=AbsorbingLayerapp(sPParray(ii),15e-6,16);
        MatrixsPP(ii,1)=Matrix(1,5);
        MatrixsPP(ii,2)=sum(Matrix(:,3))/length(Matrix(:,3));
        MatrixsPP(ii,3)=std(Matrix(:,3));
    end
%    MatrixsPP
    figure;[AX,H1,H2] = plotyy(MatrixsPP(:,1),MatrixsPP(:,2),...
        MatrixsPP(:,1),MatrixsPP(:,3),'semilogx','loglog');
    set(get(AX(1),'Ylabel'),'String','Im(n_{eff})x10^4'); 
    set(get(AX(2),'Ylabel'),'String','Standard deviation');
    set(get(AX(1),'Xlabel'),'String','s');
    set(H1,'LineWidth',2);
    set(H2,'LineStyle','--','LineWidth',2,'Color','r');
    ylim(AX(1),[1.575e-4 1.585e-4]);set(AX(1),'ytickMode','auto');
    ylim(AX(2),[1e-7 1e-4]);set(AX(2),'ytickMode','auto');
    xlim(AX(1),[0.01 10]);set(AX(2),'xtickMode','auto');
    xlim(AX(2),[0.01 10]);set(AX(2),'xtickMode','auto');
end;


if FigNum==27||FigNum==28||FigNum==29||FigNum==30
    AbsorbingLayer(1.418,0,15,500,15,1,5,1,FigNum);
end;
