%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%

function Ey = ThreeLayerPlotback(n1,n2,a,XLength,deltaX,wavenumber,beta,ShinkXLengthFactor)

sq=inline('xinput*xinput','xinput');

if( sq(beta/wavenumber)<sq(n1) && sq(beta/wavenumber)>sq(n2))

	kapa=sqrt(sq(wavenumber*n1)-sq(beta));
	sigma=sqrt(sq(beta)-sq(wavenumber*n2));
    x = deltaX*(-round(XLength/ShinkXLengthFactor/deltaX):round(XLength/ShinkXLengthFactor/deltaX));
	Ey=cos(kapa*x);
	Ey(abs(x)>=a)=cos(kapa*a)*exp(-sigma*(abs(x(abs(x)>=a))-a));
else

	sigma=sqrt(sq(wavenumber*n1)-sq(beta));
	rho=sqrt(sq(wavenumber*n2)-sq(beta));
	Ce=1;
	De=Ce/2*exp(i*rho*a)*(cos(sigma*a)-i*sigma/rho*sin(sigma*a));
	Fe=conj(De);

	x = deltaX*(-round(XLength/ShinkXLengthFactor/deltaX):round(XLength/ShinkXLengthFactor/deltaX));
    Ey=Ce*cos(sigma*x);
	Ey(abs(x)>=a)=De*exp(-i*rho*abs(x(abs(x)>=a)))+Fe*exp(i*rho*abs(x(abs(x)>=a)));
	numa= floor((XLength/ShinkXLengthFactor-a)/deltaX);
    fmax = (max(abs(Ey(end-numa+1:end))));
	Ey = Ey/fmax;
    Ce=Ce/fmax;

end;

