%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%


function ThreeLayerPropagation(A,A0,beta,beta0,n1,n2,a,numSeries,wavenumber,...
        XLength,deltaX,ShinkXLengthFactor)
    
sq=inline('x.*x','x');


FONT_SIZE=20;
format long;

lambda = 2*pi/wavenumber;
if (XLength/ShinkXLengthFactor/lambda<10)
    ShinkXLengthFactor=ShinkXLengthFactor/10;
end;
LightSpeed = 2.99e8;
omega = wavenumber*LightSpeed;




ZNum=100;
XNum = round(XLength/ShinkXLengthFactor/deltaX);

ZLength=10*lambda;
rho= sqrt(sq(n2*wavenumber)-beta.*beta);
omegawidth = rho(2:end) - rho(1:end-1);
omegawidth = [omegawidth omegawidth(end)];
x=linspace(-XLength,XLength,XNum*2+1)/ShinkXLengthFactor/lambda;
x_plot=linspace(-10,10,101);

DeltaZ = ZLength/ZNum;
Matrix_XPos = ones(ZNum,1)*x_plot;
Matrix_ZPos = linspace(DeltaZ,ZLength,ZNum)'*ones(1,length(x_plot))/lambda;

ZLengthNeg = lambda;
ZNumNeg=ZLengthNeg/DeltaZ;
Matrix_XNeg = ones(ZNumNeg+1,1)*x_plot;
Matrix_ZNeg = linspace(-ZLengthNeg,0,ZNumNeg+1)'*ones(1,length(x_plot))/lambda;

tNum=10;
tTotal =2*pi/omega;
tArray=tTotal/tNum:tTotal/tNum:tTotal;






figure;


for tii=1:tNum
  Vector_T = tArray(tii) ;
  MatrixPos=zeros(ZNum,length(x_plot));
  Vector_Z = linspace(1,ZNum,ZNum)*DeltaZ;
  fprintf('Generating figure %d/10\n',tii);


  
  MatrixNeg =zeros(ZNumNeg+1,length(x_plot));
  Vector_ZNeg = -1* linspace(ZNumNeg,0,ZNumNeg+1)*DeltaZ;


  for ii=1:ZNum
           	tempii=A0*ThreeLayerPlotback(n1,n2,a,XLength,deltaX,wavenumber,beta0,ShinkXLengthFactor)...
            	*exp(i*(beta0*Vector_Z(ii)-omega*Vector_T));
            MatrixPos(ii,:)=interp1(x,tempii,x_plot,'linear');
  end;
  for ii=1:ZNumNeg+1
           	tempii=A0...
                *ThreeLayerPlotback(n1,n2,a,XLength,deltaX,wavenumber,beta0,ShinkXLengthFactor)...
            	*exp(i*(wavenumber*Vector_ZNeg(ii)-omega*Vector_T));
            MatrixNeg(ii,:)=interp1(x,tempii,x_plot,'linear');
  end;

  
  for nii=1:numSeries
    tempii=A(nii)*ThreeLayerPlotback(n1,n2,a,XLength,deltaX,wavenumber,beta(nii),ShinkXLengthFactor)*...
			omegawidth(nii);
     tempii=   interp1(x,tempii,x_plot,'linear');
    for ii=1:ZNum
		MatrixPos(ii,:)=MatrixPos(ii,:)+tempii*exp(i*(beta(nii)*Vector_Z(ii)-omega*Vector_T));
    end;
    for ii=1:ZNumNeg+1
        MatrixNeg(ii,:)=MatrixNeg(ii,:)+tempii*exp(i*(wavenumber*Vector_ZNeg(ii)-omega*Vector_T));
    end;
  end;
  Matrix_Z = [Matrix_ZNeg;Matrix_ZPos];
  Matrix_X = [Matrix_XNeg;Matrix_XPos];
  Matrix =   [MatrixNeg;MatrixPos];
  Matrix = Matrix / max(max(abs(Matrix)));

  figure(1);hold off;


  [ct,h,cf] = contourf(Matrix_X,Matrix_Z,real(Matrix),linspace(-1,1,20));
  
  for k = 1:length(h)	set(h(k),'linestyle','none'); end;
  set(gca,'xtick',[-10 -5 0 5 10],'XTickLabel',[]);
  set(gca,'ytick',[-1 0 1 2 3 4 5 6 7 8 9 10],'YTickLabel',[]);

  set(gca,'FontSize',16,'FontName','Times New Roman','TickDir','out');
  tls = [0.03 0.25];set(gca,'TickLength',tls);

  hold on;
  plot([min(Matrix_X(1,:)) max(Matrix_X(1,:))],[0 0],'k:','LineWidth',2);
  plot([min(Matrix_X(1,:)) max(Matrix_X(1,:))],[min(Matrix_Z(:,1)) min(Matrix_Z(:,1))],'k');
  plot([min(Matrix_X(1,:)) max(Matrix_X(1,:))],[max(Matrix_Z(:,1)) max(Matrix_Z(:,1))],'k');
  plot([min(Matrix_X(1,:)) min(Matrix_X(1,:))],[min(Matrix_Z(:,1)) max(Matrix_Z(:,1))],'k');
  plot([max(Matrix_X(1,:)) max(Matrix_X(1,:))],[min(Matrix_Z(:,1)) max(Matrix_Z(:,1))],'k');

  plot([-a/lambda -a/lambda],[min(Matrix_Z(:,1)) max(Matrix_Z(:,1))],'k--','LineWidth',2);
  plot([a/lambda a/lambda],[min(Matrix_Z(:,1)) max(Matrix_Z(:,1))],'k--','LineWidth',2);
   
  
  caxis([-1,1]);
  hold on;

  box on;

  colorbar('YTickLabel',' ');
  htxt = text(0,0,'1');
  set(htxt,'Position',[12.5 10],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
  htxt = text(0,0,'-1');
  set(htxt,'Position',[12.5 -0.9],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
  htxt = text(0,0,'{\it x}/\lambda');
  set(htxt,'Position',[-1.5 -1.9],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE*1.6);
  htxt = text(0,0,'{\it z}/\lambda');
  set(htxt,'Rotation',90,'Position',[-12 4],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE*1.6);
  htxt = text(0,0,'-10');
  set(htxt,'Position',[-11 -2],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
  htxt = text(0,0,'10');
  set(htxt,'Position',[9.5 -2],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
  htxt = text(0,0,'10');
  set(htxt,'Position',[-12.2 10],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
  htxt = text(0,0,'0');
  set(htxt,'Position',[-11.7 0],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
  htxt = text(0,0,'-1');
  set(htxt,'Position',[-12.2 -1],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);

  m=100+tii;
  print ('-dpsc2',strcat('movie/Fig7_',int2str(m),'.ps'));


end;

