%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%

function WType(numSeries,NormXLength,RatioInputwidth,Ratioba,ShinkXLengthFactor,FigNumber)



TestSign=0;
sq=inline('x.*x','x');
n1=1.45;
n2=0.96*n1;
n3=n1;
lambda=1e-6;wavenumber=2*pi/lambda;
a=sqrt(1/wavenumber^2/(n1^2-n2^2));

b=Ratioba*a;
SpeedLight=2.99e8;
A = zeros(1,numSeries);
XLength = NormXLength*a;
DeltaX=a/10;

NumPoints = XLength/DeltaX;
x=(-NumPoints:NumPoints)*DeltaX;
omega=2*pi/2/XLength;

plotsign=0;


width=a;fx=exp(-x.^2/2/width/width);


if(exp(-(XLength/ShinkXLengthFactor).^2/2/width/width)>1e-10)
        fprintf('ShinkXLengthFactor is too big =%e\n,please reset ShinkXLengthFactor\n',exp(-XLength/ShinkXLengthFactor.^2/2/width/width));
        stop

end;

gamma = WTypeGetgammaSet(n1,n2,a,b,XLength,wavenumber,numSeries,plotsign); 

fprintf('Finish WTypeGetgammaSet\n');
beta= sqrt(sq(n3*wavenumber)-gamma.*gamma);
rho = sqrt(sq(n2*wavenumber)-beta.*beta);
Ce=zeros(1,numSeries); 
Ae=zeros(numSeries,1);
fprintf('Calculating decomposition coefficient\n');
for	nii=1:numSeries
	[A(nii) Ce(nii) Ae(nii)]=WTypeGetCouplingCoeff(width,n1,n2,a,b,...
            XLength,DeltaX,wavenumber,beta(nii),ShinkXLengthFactor);
end;

fprintf('Finish WTypeGetCouplingCoeff\n');
[Meff Ieff] = max(Ce);
betamax = beta(Ieff);
Eff = betamax/wavenumber;
fprintf('Approximate effecitve index is %f\n',Eff);


omegawidth = gamma(2:end) - gamma(1:end-1);
omegawidth = [omegawidth omegawidth(end)];



if TestSign==1
    fprintf('Test decomposition\n');
    fxappr = zeros(1,length(x));
    for	nii=1:numSeries
        fxappr=fxappr+A(nii)*omegawidth(nii)*WTypePlotback(Ce(nii),n1,n2,a,b,XLength,DeltaX,...
            wavenumber,beta(nii),plotsign);

    end;
    figure;	plot(x/a,[fx; fxappr]);	axis([min(x)/a,max(x)/a,-0.2,1]); 
    error = log10(sum(abs(fxappr-fx))/length(fx));
    fprintf('error = %f, dk*z = %f\n',error,omega/SpeedLight*5*lambda);
    %semilogy(x/a,[fxappr; fx]);
    axis([min(x/a),max(x/a),-0.1, 1]);
    stop
end;


if FigNumber==11
    figure;[AX,H1,H2] = plotyy(gamma/wavenumber,abs(A).^2/max(abs(A).^2),...
        gamma/wavenumber,real(beta/wavenumber));
    set(get(AX(1),'Ylabel'),'String','P(k_x)'); 
    set(get(AX(2),'Ylabel'),'String','Re(n_{eff})');
    set(get(AX(1),'Xlabel'),'String','k_x/k_0');
    set(H1,'LineWidth',2);
    set(H2,'LineStyle','--','LineWidth',2,'Color','r');
    ylim(AX(2),[0 2]);set(AX(2),'ytickMode','auto');
    xlim(AX(1),[0 1]);set(AX(2),'ytickMode','auto');
    xlim(AX(2),[0 1]);set(AX(2),'ytickMode','auto');
end;



if(FigNumber==12)
    WTypePropagation(A,Ce,beta,n1,n2,a,b,numSeries,wavenumber,...
        plotsign);
end;

if(FigNumber==13)
    WTypeVaryb(width,A,Ce,beta,n1,n2,a,b,numSeries,wavenumber,...
        XLength,DeltaX,ShinkXLengthFactor,plotsign);
end;

if(FigNumber==14)
    WTypeModeEvolution(A,Ce,beta,n1,n2,a,b,numSeries,...
        wavenumber,plotsign);
end;


if FigNumber==15;
    format long;
    ZLength=500*lambda; 
    ZNum=200;
    DeltaZ = ZLength/ZNum;
    z=linspace(1,ZNum,ZNum)'*DeltaZ;
    y2L=zeros(ZNum,1);
    for nii=1:numSeries
        y2L=y2L+A(nii)*Ce(nii)*omegawidth(nii)*exp(i*beta(nii)*z);
    end;
    WTypeSteepestDecent(z,y2L,A,Ce,beta,n1,n2,a,b,wavenumber,plotsign);
end;



