%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%

function [realne imagne] = WTypeLeaky(n1,n2,baratio,wavenumber,plotsign)
sq=inline('x.*x','x');

m=0;

fprintf('in beginning of WTypeLeaky plotsign  = %d\n',plotsign);
Numreal=20;
NumImag=10;
Breal=linspace(n2,n1,Numreal+2);
Breal=Breal(2:end-1);
Bimag=-1*logspace(-1,-20,NumImag)';
n3=n1;
lambda=2*pi/wavenumber;
a=sqrt(1/wavenumber^2/(n1^2-n2^2));
b=baratio*a;





X=zeros(Numreal,NumImag);
Y=zeros(Numreal,NumImag);
Z=zeros(Numreal,NumImag);
for ii=1:Numreal
  for jj=1:NumImag
    X(ii,jj)=Breal(ii);
    Y(ii,jj)=Bimag(jj);
    Z(ii,jj)=WTypeEigen(Breal(ii), Bimag(jj),n1,n2,n3,a,b,wavenumber,m);
  end;
end;

[D I]=min(Z);
[E J]=min(D);
Z(I(J),J);
fprintf('mode located around r=%.10f i=%.15f \n',X(I(J),J),Y(I(J),J));



newx=X(I(J),J)+i*Y(I(J),J);
x=newx+1;
IterationCount =0;
while((abs(real(newx-x)/real(x))>1e-10|abs(imag(newx-x)/imag(x))>1e-10)&IterationCount<50)
        x=newx;
        deltaR =  1e-12;
        F0=WTypeEigen(real(x),imag(x),n1,n2,n3,a,b,wavenumber,m);
        F1=WTypeEigen(real(x+deltaR),imag(x),n1,n2,n3,a,b,wavenumber,m);
        DifF = F1-F0;
        newx = x-(conj(DifF)/sq(abs(F1-F0))*deltaR*F0);

        fprintf('search for mode at %.22f+i*%.22f correct =%.22f+i*%.22f EigenEq=%.10f\n',...
            real(newx),imag(newx),real((newx-x)/newx),imag((newx-x)/newx),abs(F1));
        IterationCount=IterationCount+1;

end;

if(IterationCount<50)
	fprintf('b= %.2f*a mode search located at r=%.15f %.9e itr = %d  \n',b/a,real(x),imag(x),IterationCount);
else
	fprintf('failed b= %.2f*a mode search located at r=%.15f %.9e itr = %d  \n',b/a,real(x),imag(x),IterationCount);
    
end;


realne=real(x);
imagne=imag(x);

if(plotsign==1)
    Numreal=100;
    NumImag=100;
    Breal=1e-4*linspace(5,7,Numreal);
    Bimag=1*1e-4*linspace(1,2,NumImag);
    X=zeros(Numreal,NumImag);
    Y=zeros(Numreal,NumImag);
    Z=zeros(Numreal,NumImag);
    for ii=1:Numreal
        for jj=1:NumImag
            X(ii,jj)=Breal(ii);
            Y(ii,jj)=Bimag(jj);
            Z(ii,jj)=log10(abs(WTypeEigen(Breal(ii)+1.418, Bimag(jj),n1,n2,n3,a,b,wavenumber,m)));
        end;
    end;
    figure;
    [C,h] = contour3(X,Y,Z,linspace(-2,-5,40));
    caxis([-5,-2]);
    zlim([-5 -2]);
    set(gca,'XTick',[5e-4,5.5e-4,6e-4,6.5e-4],'YTick',[1e-4,1.2e-4,1.4e-4,1.6e-4,1.8e-4,2e-4]);
 %   set(gca,'XTickLabel',[],'YTickLabel',[],'ZTickLabel',[]);
 xlabel('Re(n_{eff})-1.418');
 ylabel('Im(n_{eff})');
 zlabel('log_{10}(|e|)');
%	colorbar('YTickLabel',' ');
 colorbar;   
end;













