%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%
function Matrix0 = WTypeModeEvolution(A,Ce,beta,n1,n2,a,b,numSeries,...
        wavenumber,plotsign)

sq=inline('x.*x','x');
FONT_SIZE=30;

XLength = 300*a;
DeltaX=a;
XNum = round(XLength/DeltaX)
ZNum=100;


Matrix0=zeros(ZNum,1);
lambda=2*pi/wavenumber;
ZLength=500*lambda;
DeltaZ = ZLength/ZNum;
gamma= sqrt(sq(n1*wavenumber)-beta.*beta);
omegawidth = gamma(2:end) - gamma(1:end-1);
omegawidth = [omegawidth omegawidth(end)];


n3=n1;
lambda = 2*pi/wavenumber;

x=linspace(-XNum,XNum,2*XNum+1)*DeltaX;
Vector_Z = linspace(0,ZNum,ZNum+1)*DeltaZ;


[realne imagne] =WTypeLeaky(n1,n2,b/a,wavenumber,plotsign);

fprintf('result from WTypeLeaky Neff = %f+ %f*i \n',realne,imagne);
n = realne+i*imagne;
u=a*wavenumber*sqrt(n1^2-n^2);
w=a*wavenumber*sqrt(n3^2-n^2);
tpp=a*wavenumber*sqrt(n^2-n2^2);
C=-1*atanh(i*w/tpp)-tpp/a*b;
h1=wavenumber*sqrt(n1^2-n^2);
h2=wavenumber*sqrt(n^2-n2^2);
h3=h1;
numPoints=100;
x1=-a:DeltaX:a;

Ey1=cos(u/a*x1);
x2=a+DeltaX:DeltaX:b;


C=-1*atanh(i*w/tpp)-tpp/a*b;
Ey2=cos(u)*cosh(tpp/a*x2+C)/cosh(tpp+C);
x3=b+DeltaX:DeltaX:XLength;
Ey3=cos(u)*cosh(tpp/a*b+C)/cosh(tpp+C)*exp(i*w/a*(x3-b));
xLeaky = [-1*fliplr(x3) -1*fliplr(x2) x1 x2 x3];
EyLeaky = [fliplr(Ey3) fliplr(Ey2) Ey1 Ey2 Ey3];

MatrixPlotback = zeros(numSeries,2*XNum+1);

for nii=1:numSeries
   temp = WTypePlotback(Ce(nii),n1,n2,a,b,...
            XLength,DeltaX,wavenumber,beta(nii));
   MatrixPlotback(nii,:) = A(nii)*temp*omegawidth(nii);
end;



for zii=1:ZNum+1
    close all;
    figure; hold off;
    fprintf('Generating figure %d/%d\n',zii,ZNum+1);
    MatrixPos=MatrixPlotback.'*exp(i*beta.'*Vector_Z(zii));
    MatrixPos = MatrixPos/max(MatrixPos);
    subplot(2,1,1);
    pos = get(gca, 'Position');
    set(gca,'Position', [pos(1) pos(2)-0.3 pos(3) pos(4)+0.3 ]);
    plot(x/lambda,log10(sq(abs(MatrixPos))),'b','LineWidth',2);hold on;
    set(gca,'XTickLabel',[]);
    set(gca,'ytick',[-3 -2 -1 0],'YTickLabel',[]);
    plot(xLeaky/lambda,log10(sq(abs(EyLeaky))),'r--','linewidth',2);
    axis([-100 100 -3 0]);
    tls = [0.04 0.25];set(gca,'TickLength',tls);

  
    %  plot([-a/lambda -a/lambda],[-3 0],'k--','LineWidth',1);
    %  plot([a/lambda a/lambda],[-3 0],'k--','LineWidth',1);
    plot([-b/lambda -b/lambda],[-3 0],'k--','LineWidth',2);
    plot([b/lambda b/lambda],[-3 0],'k--','LineWidth',2);

  
    htxt = text(0,0,'0');
    set(htxt,'Position',[-105 -4],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
    htxt = text(0,0,'500');
    set(htxt,'Position',[90 -4],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
    htxt = text(0,0,'{\it z} /{\it \lambda}');
    set(htxt,'Position',[-16 -4],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
    hs = uicontrol('style','slider','position',[100 65 600 20],'Min',1,'Max',ZNum+1,'SliderStep',[0.1  0.05]);
    set(hs,'Value',zii)                        
  	htxt = text(0,0,'{\it x} /{\it \lambda}');
	set(htxt,'Position',[-18 -3.2],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE*1.2);
	htxt = text(0,0,'Normalized power');
	set(htxt,'Rotation',90,'Position',[-115 -2.5],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE*0.9);
	htxt = text(0,0,'-100');
	set(htxt,'Position',[-115 -3.25],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	htxt = text(0,0,'100');
	set(htxt,'Position',[90 -3.25],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	htxt = text(0,0,'10');
	set(htxt,'Position',[-120 0],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	htxt = text(0,0,'10');
	set(htxt,'Position',[-120 -3],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE);
	htxt = text(0,0,'0');
	set(htxt,'Position',[-105 0.1],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE/1.5);
	htxt = text(0,0,'-3');
	set(htxt,'Position',[-110 -2.85],'FontName', 'TimesNewRoman','FontSize',FONT_SIZE/1.5);
 
    m=100+zii;
    print('-dpsc2',strcat('movie/Fig14_',int2str(m),'.ps'));
  
end;

