%
%
%   UndStdLeakyMode
%   Understand leaky modes: Slab waveguide revisited
%
%   Copyright (2008)
%   Computational Photonics Laboratory
%   University of Maryland Baltimore County
%   
%   By Jonathan Hu
%
function [A Ce StartPower neff]=WTypeRadiationMode(A,Ce,beta,n1,n2,a,b,wavenumber);

numSerCeCoeff=500;

sq=inline('x.*x','x');
[M I] = max(Ce);

betaAmp = linspace(beta(I-5), beta(I+5),numSerCeCoeff);

n3=n1;
gammaAmp= sqrt(sq(n3*wavenumber)-betaAmp.*betaAmp);
rhoAmp = sqrt(sq(n2*wavenumber)-betaAmp.*betaAmp);

CeCoeff=zeros(numSerCeCoeff,5);

% note that /2 is included
CeCoeff(:,1) = (1+rhoAmp./gammaAmp)/2.*exp(i*rhoAmp*a).*(cos(gammaAmp*a)...
        -i*gammaAmp./rhoAmp.*sin(gammaAmp*a)).*exp(-i*(rhoAmp-gammaAmp)*b);
CeCoeff(:,2) = (1-rhoAmp./gammaAmp)/2.*exp(-i*rhoAmp*a).*(cos(gammaAmp*a)...
        +i*gammaAmp./rhoAmp.*sin(gammaAmp*a)).*exp(i*(rhoAmp+gammaAmp)*b);
CeCoeff(:,3) = CeCoeff(:,1) + CeCoeff(:,2);
CeCoeff(:,4) = 1./abs(CeCoeff(:,3));
NumSpace=1;

[M I] = max(CeCoeff(:,4));


Ce1P=(CeCoeff(I+NumSpace,1)-CeCoeff(I-NumSpace,1))/(gammaAmp(I+NumSpace)-gammaAmp(I-NumSpace));
Ce10=CeCoeff(I,1)-gammaAmp(I)*Ce1P;
Ce2P=(CeCoeff(I+NumSpace,2)-CeCoeff(I-NumSpace,2))/(gammaAmp(I+NumSpace)-gammaAmp(I-NumSpace));
Ce20=CeCoeff(I,2)-gammaAmp(I)*Ce2P;




gamma= sqrt(sq(n3*wavenumber)-beta.*beta);
Ce=1./abs(Ce10+Ce1P.*gamma+Ce20+Ce2P.*gamma);
x0=(Ce10+Ce20)/(Ce1P+Ce2P);
neff = sqrt(sq(n1*wavenumber)-sq(x0))/wavenumber;
A = max(A)*Ce/max(Ce);
StartPower = 2*pi*i*max(A)/max(Ce)/sq(abs(Ce1P+Ce2P))/2/i/imag(x0);


